@@ -14,7 +14,9 @@ def report(message: str) -> None:
         )
 
     anyscale.util.send_json_request(
-        "session_report_command",
-        {"session_command_id": int(session_command_id), "message": message},
+        "/api/v2/session_commands/{session_command_id}/report_command".format(
+            session_command_id=int(session_command_id)
+        ),
+        {"message": message},
         method="POST",
     )
