@@ -13,9 +13,11 @@ import click
 import ray.ray_constants
 import requests
 
-from anyscale.conf import SNAPSHOT_REPO, SNAPSHOT_REPO_PASSWORD, TEST_V2
+from anyscale.conf import SNAPSHOT_REPO, SNAPSHOT_REPO_PASSWORD
+from anyscale.feature_flags import FLAG_KEY_USE_SNAPSHOT
 from anyscale.project import get_project_id
 from anyscale.util import (
+    check_is_feature_flag_on,
     confirm,
     get_cluster_config,
     get_requirements,
@@ -397,100 +399,37 @@ def create_snapshot(
         )
     else:
         requirements = ""
-    if TEST_V2:
-        resp = send_json_request(
-            "/api/v2/snapshots/",
-            {
-                "project_id": project_id,
-                "project_config": json.dumps(project_definition.config),
-                "cluster_config": json.dumps(cluster_config),
-                "requirements": requirements,
-                "description": description if description else "",
-                "tags": tags,
-            },
-            method="POST",
-        )
-        snapshot_uuid: str = resp["result"]["id"]
-        creds = resp["result"]["credentials"]
-    else:
-        resp = send_json_request(
-            "snapshot_create",
-            {
-                "project_id": project_id,
-                "project_config": json.dumps(project_definition.config),
-                "cluster_config": json.dumps(cluster_config),
-                "requirements": requirements,
-                "description": description if description else "",
-                "tags": tags,
-            },
-            method="POST",
-        )
-        snapshot_uuid = resp["uuid"]
-        creds = resp["credentials"]
 
-    try:
-        snapshot_runner.upload(
-            snapshot_uuid, project_dir, additional_files, files_only, creds
-        )
-    except (OSError, AssertionError) as e:
-        # Tell the server to delete the snapshot.
-        delete_snapshot(project_dir, snapshot_uuid, True)
-        raise e
+    resp = send_json_request(
+        "/api/v2/snapshots/",
+        {
+            "project_id": project_id,
+            "project_config": json.dumps(project_definition.config),
+            "cluster_config": json.dumps(cluster_config),
+            "requirements": requirements,
+            "description": description if description else "",
+            "tags": tags,
+        },
+        method="POST",
+    )
+    snapshot_uuid: str = resp["result"]["id"]
+
+    if check_is_feature_flag_on(FLAG_KEY_USE_SNAPSHOT):
+        creds = resp["result"]["credentials"]
+
+        try:
+            snapshot_runner.upload(
+                snapshot_uuid, project_dir, additional_files, files_only, creds
+            )
+        except (OSError, AssertionError):
+            pass
+
     return snapshot_uuid
 
 
-def delete_snapshot(project_dir: str, uuid: str, yes: bool) -> None:
-    """Delete the snapshot(s) with the given name.
-
-    Delete the snapshot data from disk and the metadata from the database.
-
-    Args:
-        project_dir: Project root directory.
-        uuid: The UUID of the snapshot to delete.
-        yes: Don't ask for confirmation.
-
-    Raises:
-        ValueError: If the current project directory does not match the project
-            metadata entry in the database.
-    """
-    # Find and validate the current project ID.
-    project_id = get_project_id(project_dir)
-
-    # Get the snapshots with the requested name.
-    resp = send_json_request(
-        "snapshot_list", {"project_id": project_id, "snapshot_uuid": uuid}
-    )
-    snapshots = resp["snapshots"]
-    if snapshots:
-        snapshots_str = "\n".join(snapshot["uuid"] for snapshot in snapshots)
-        confirm("Delete snapshots?\n{}".format(snapshots_str), yes)
-        snapshot_uuids = [snapshot["uuid"] for snapshot in snapshots]
-        if TEST_V2:
-            resp = send_json_request(
-                "/api/v2/snapshots/{}".format(uuid), {}, method="DELETE"
-            )
-            resp = resp["result"]
-        else:
-            resp = send_json_request(
-                "snapshot_delete", {"snapshot_uuids": snapshot_uuids}, method="POST"
-            )
-
-        assert "credentials" in resp
-
-        snapshot_runner = SnapshotRunner()
-        for name in snapshot_uuids:
-            snapshot_runner.delete(name, resp["credentials"])
-
-    else:
-        logger.warn("No snapshots found with UUID %s", uuid)
-
-
 def describe_snapshot(uuid: str) -> Any:
-    if TEST_V2:
-        resp = send_json_request("/api/v2/snapshots/{}".format(uuid), {})
-        return resp["result"]
-    else:
-        return send_json_request("snapshot_describe", {"snapshot_uuid": uuid})
+    resp = send_json_request("/api/v2/snapshots/{}".format(uuid), {})
+    return resp["result"]
 
 
 def list_snapshots(project_dir: str) -> List[str]:
@@ -508,9 +447,9 @@ def list_snapshots(project_dir: str) -> List[str]:
     """
     # Find and validate the current project ID.
     project_id = get_project_id(project_dir)
-    resp = send_json_request("snapshot_list", {"project_id": project_id})
-    snapshots = resp["snapshots"]
-    return [snapshot["uuid"] for snapshot in snapshots]
+    resp = send_json_request("/api/v2/snapshots/", {"project_id": project_id})
+    snapshots = resp["result"]["snapshots"]
+    return [snapshot["id"] for snapshot in snapshots]
 
 
 def get_snapshot_uuid(project_dir: str, snapshot_uuid: str) -> str:
@@ -524,10 +463,8 @@ def get_snapshot_uuid(project_dir: str, snapshot_uuid: str) -> str:
     """
     # Find and validate the current project ID.
     project_id = get_project_id(project_dir)
-    resp = send_json_request(
-        "snapshot_list", {"project_id": project_id, "snapshot_uuid": snapshot_uuid}
-    )
-    snapshots = resp["snapshots"]
+    resp = send_json_request("/api/v2/snapshots/", {"project_id": project_id})
+    snapshots = resp["result"]["snapshots"]
     if len(snapshots) == 0:
         raise ValueError("No snapshots found with name {}".format(snapshot_uuid))
     snapshot_idx = 0
@@ -545,7 +482,7 @@ def get_snapshot_uuid(project_dir: str, snapshot_uuid: str) -> str:
         snapshot_idx -= 1
         if snapshot_idx < 0 or snapshot_idx > len(snapshots):
             raise ValueError("Snapshot index {} is out of range".format(snapshot_idx))
-    result: str = snapshots[snapshot_idx]["uuid"]
+    result: str = snapshots[snapshot_idx]["id"]
     return result
 
 
