@@ -6,7 +6,7 @@ import re
 import sys
 import threading
 import time
-from typing import Any, Dict, Iterator, List
+from typing import Any, cast, Dict, Iterator, List
 import unicodedata
 
 import boto3
@@ -14,11 +14,11 @@ import botocore
 from botocore.config import Config
 import click
 import requests
+from requests import Response
 import yaml
 
-from anyscale.common import ENDPOINTS
 import anyscale.conf
-
+from anyscale.feature_flags import FLAG_KEY_USE_SNAPSHOT
 
 logger = logging.getLogger(__file__)
 
@@ -30,11 +30,7 @@ def confirm(msg: str, yes: bool) -> Any:
 
 
 def get_endpoint(endpoint: str) -> str:
-    if endpoint.startswith("/"):
-        route = endpoint
-    else:
-        route = ENDPOINTS[endpoint]
-    return "{}{}".format(anyscale.conf.ANYSCALE_HOST, route)
+    return "{}{}".format(anyscale.conf.ANYSCALE_HOST, endpoint)
 
 
 def load_credentials() -> str:
@@ -66,9 +62,9 @@ def load_credentials() -> str:
     return credentials["cli_token"]
 
 
-def send_json_request(
+def send_json_request_raw(
     endpoint: str, json_args: Dict[str, Any], method: str = "GET"
-) -> Dict[str, Any]:
+) -> Response:
     if anyscale.conf.CLI_TOKEN is None:
         anyscale.conf.CLI_TOKEN = load_credentials()
 
@@ -83,13 +79,23 @@ def send_json_request(
             resp = requests.delete(url, json=json_args, cookies=cookies)
         elif method == "PATCH":
             resp = requests.patch(url, data=json_args, cookies=cookies)
+        elif method == "PUT":
+            resp = requests.put(url, json=json_args, cookies=cookies)
         else:
-            assert "unknown method {}".format(method)
+            assert False, "unknown method {}".format(method)
     except requests.exceptions.ConnectionError:
         raise click.ClickException(
             "Failed to connect to anyscale server at {}".format(url)
         )
 
+    return resp
+
+
+def send_json_request(
+    endpoint: str, json_args: Dict[str, Any], method: str = "GET"
+) -> Dict[str, Any]:
+    resp = send_json_request_raw(endpoint, json_args, method=method)
+
     if not resp.ok:
         raise click.ClickException("{}: {}.".format(resp.status_code, resp.text))
 
@@ -115,6 +121,9 @@ def serialize_datetime(d: datetime.datetime) -> str:
 
 
 def deserialize_datetime(s: str) -> datetime.datetime:
+    if sys.version_info < (3, 7) and ":" == s[-3:-2]:
+        s = s[:-3] + s[-2:]
+
     return datetime.datetime.strptime(s, "%Y-%m-%dT%H:%M:%S.%f%z")
 
 
@@ -257,3 +266,41 @@ class Timer:
         self.busy = False
         self.start_time = 0.0
         time.sleep(1)
+
+
+def check_is_feature_flag_on(flag_key: str) -> bool:
+    use_snapshot_resp = send_json_request(
+        "/api/v2/userinfo/check_is_feature_flag_on", {"flag_key": flag_key},
+    )
+
+    return cast(bool, use_snapshot_resp["result"]["is_on"])
+
+
+def get_active_sessions(project_id: int, session_name: str) -> Any:
+    response = anyscale.util.send_json_request(
+        "/api/v2/sessions/",
+        {"project_id": project_id, "name": session_name, "active_only": True},
+    )
+    return response["results"]
+
+
+def wait_for_session_start(project_id: int, session_name: str) -> int:
+    print(f"Waiting for session {session_name} to start.")
+    while True:
+        sessions = get_active_sessions(project_id, session_name)
+        if len(sessions) > 0:
+            if not sessions[0]["starting_up"]:
+                return cast(int, sessions[0]["id"])
+        time.sleep(5)
+
+
+def install_anyscale_hooks(cluster_config: Dict[str, Any]) -> None:
+    "Add anyscale hooks into the cluster configuration."
+
+    cluster_config["setup_commands"].insert(
+        0,
+        # The grep line makes sure that the new line
+        # is not added again to the ~/.bashrc if it is already there.
+        'grep -qF -- "export RAY_ADDRESS=localhost:6379" ~/.bashrc '
+        '|| echo "export RAY_ADDRESS=localhost:6379" >> ~/.bashrc',
+    )
